Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2401)

Unified Diff: ash/system/tray/tray_item_view.h

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/system/tray/system_tray_bubble.cc ('k') | ash/system/tray/tray_item_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/system/tray/tray_item_view.h
diff --git a/ash/system/tray/tray_item_view.h b/ash/system/tray/tray_item_view.h
index e0d8ec4d5af6c0f2ed5cc1679b0232d4b0d337e5..761e918791cead1c3e0ec262be2dd57dcafafb55 100644
--- a/ash/system/tray/tray_item_view.h
+++ b/ash/system/tray/tray_item_view.h
@@ -6,10 +6,10 @@
#define ASH_SYSTEM_TRAY_TRAY_ITEM_VIEW_H_
#include "ash/ash_export.h"
-#include "ui/base/animation/animation_delegate.h"
+#include "ui/gfx/animation/animation_delegate.h"
#include "ui/views/view.h"
-namespace ui {
+namespace gfx {
class SlideAnimation;
}
@@ -28,7 +28,7 @@ namespace internal {
// correctly when the visibility/size of the tray item changes. It also adds
// animation when showing/hiding the item in the tray.
class ASH_EXPORT TrayItemView : public views::View,
- public ui::AnimationDelegate {
+ public gfx::AnimationDelegate {
public:
explicit TrayItemView(SystemTrayItem* owner);
virtual ~TrayItemView();
@@ -66,13 +66,13 @@ class ASH_EXPORT TrayItemView : public views::View,
// Overridden from views::View.
virtual void ChildPreferredSizeChanged(View* child) OVERRIDE;
- // Overridden from ui::AnimationDelegate.
- virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationEnded(const ui::Animation* animation) OVERRIDE;
- virtual void AnimationCanceled(const ui::Animation* animation) OVERRIDE;
+ // Overridden from gfx::AnimationDelegate.
+ virtual void AnimationProgressed(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationEnded(const gfx::Animation* animation) OVERRIDE;
+ virtual void AnimationCanceled(const gfx::Animation* animation) OVERRIDE;
SystemTrayItem* owner_;
- scoped_ptr<ui::SlideAnimation> animation_;
+ scoped_ptr<gfx::SlideAnimation> animation_;
views::Label* label_;
views::ImageView* image_view_;
« no previous file with comments | « ash/system/tray/system_tray_bubble.cc ('k') | ash/system/tray/tray_item_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698